# w.c.s. - web application for online forms
# Copyright (C) 2005-2013  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import thread
import threading

from quixote import get_publisher
from .qommon.http_response import HTTPResponse
from .compat import CompatHTTPRequest, CompatWcsPublisher


class PublisherInitialisationMiddleware(object):
    '''Initializes the publisher according to the request server name.'''
    def process_request(self, request):
        pub = get_publisher()
        if not pub:
            pub = CompatWcsPublisher.create_publisher()
        compat_request = CompatHTTPRequest(request)
        pub.init_publish(compat_request)
        pub._set_request(compat_request)
        request._publisher = pub


class AfterJobsMiddleware(object):
    ASYNC = True

    def process_response(self, request, response):
        if hasattr(response, 'after_jobs') and response.after_jobs:
            http_response = HTTPResponse()
            http_response.after_jobs = response.after_jobs
            if self.ASYNC:
                thread.start_new_thread(
                        http_response.process_after_jobs,
                        (get_publisher(),))
            else:
                http_response.process_after_jobs()
        return response
